Package: ggprism
Title: A 'ggplot2' Extension Inspired by 'GraphPad Prism'
Version: 1.0.7
Authors@R: 
    person(given = "Charlotte",
           family = "Dawson",
           role = c("aut", "cre"),
           email = "csdaw@outlook.com",
           comment = c(ORCID = "0000-0002-7151-5971"))
Description: Provides various themes, palettes, and other functions
    that are used to customise ggplots to look like they were made in 'GraphPad 
    Prism'. The 'Prism'-look is achieved with theme_prism() and 
    scale_fill|colour_prism(), axes can be changed with custom guides like 
    guide_prism_minor(), and significance indicators added with add_pvalue().
License: GPL (>= 3.0)
URL: https://csdaw.github.io/ggprism/, https://github.com/csdaw/ggprism
BugReports: https://github.com/csdaw/ggprism/issues
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
Depends: R (>= 3.2)
Imports: digest, ggplot2 (>= 3.4.0), glue, grid, gtable (>= 0.1.1),
        rlang (>= 0.3.0), scales (>= 0.5.0), stats, tibble, utils
Suggests: covr, dplyr, ggbeeswarm, ggnewscale, knitr, magrittr,
        patchwork, rmarkdown, rstatix, tidyr, tinytest
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-08-23 17:04:12 UTC; csdaw
Author: Charlotte Dawson [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7151-5971>)
Maintainer: Charlotte Dawson <csdaw@outlook.com>
Repository: CRAN
Date/Publication: 2025-08-23 17:50:02 UTC
Built: R 4.6.0; ; 2026-04-28 15:04:32 UTC; unix
