# Generated by roxygen2: do not edit by hand

S3method(guide_gengrob,prism_bracket)
S3method(guide_gengrob,prism_minor)
S3method(guide_gengrob,prism_offset)
S3method(guide_gengrob,prism_offset_minor)
S3method(guide_geom,prism_axis)
S3method(guide_merge,prism_axis)
S3method(guide_train,prism_axis)
S3method(guide_train,prism_minor)
S3method(guide_train,prism_offset_minor)
S3method(guide_transform,prism_axis)
export(GeomBracket)
export(GeomTicks)
export(StatBracket)
export(add_pvalue)
export(annotation_ticks)
export(guide_prism_bracket)
export(guide_prism_minor)
export(guide_prism_offset)
export(guide_prism_offset_minor)
export(preview_theme)
export(prism_color_pal)
export(prism_colour_pal)
export(prism_fill_pal)
export(prism_shape_pal)
export(scale_color_prism)
export(scale_colour_prism)
export(scale_fill_prism)
export(scale_shape_prism)
export(theme_prism)
import(ggplot2)
importFrom(digest,digest)
importFrom(ggplot2,guide_geom)
importFrom(ggplot2,guide_merge)
importFrom(ggplot2,guide_train)
importFrom(ggplot2,guide_transform)
importFrom(glue,glue)
importFrom(glue,glue_collapse)
importFrom(glue,glue_data)
importFrom(grid,gList)
importFrom(grid,gTree)
importFrom(grid,gpar)
importFrom(grid,grid.draw)
importFrom(grid,grobHeight)
importFrom(grid,grobWidth)
importFrom(grid,segmentsGrob)
importFrom(grid,textGrob)
importFrom(grid,unit)
importFrom(grid,unit.c)
importFrom(grid,viewport)
importFrom(gtable,gtable_col)
importFrom(gtable,gtable_height)
importFrom(gtable,gtable_row)
importFrom(gtable,gtable_width)
importFrom(rlang,"!!")
importFrom(rlang,"%||%")
importFrom(rlang,":=")
importFrom(rlang,abort)
importFrom(rlang,ensym)
importFrom(rlang,exec)
importFrom(rlang,is_bool)
importFrom(rlang,warn)
importFrom(scales,alpha)
importFrom(scales,manual_pal)
importFrom(stats,setNames)
importFrom(tibble,deframe)
importFrom(utils,getFromNamespace)
importFrom(utils,packageVersion)
